@@ -4,8 +4,8 @@
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
-# Copyright 2017, 2018 The Sympa Community. See the AUTHORS.md file at the
-# top-level directory of this distribution and at
+# Copyright 2017, 2018, 2021 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -135,6 +135,30 @@ sub check_new_listname {
             {new_listname => $listname});
     }
 
+    # Prevent to use prohibited listnames
+    my $regex = '';
+    if ($Conf::Conf{'prohibited_listnames_regex'}) {
+        $regex = eval(sprintf 'qr(%s)',
+            $Conf::Conf{'prohibited_listnames_regex'} // '');
+    }
+    if ($Conf::Conf{'prohibited_listnames'}) {
+        foreach my $l (split ',', $Conf::Conf{'prohibited_listnames'}) {
+            $l =~ s/([^\s\w\x80-\xff])/\\$1/g;
+            $l =~ s/(\\.)/$1 eq "\\*" ? '.*' : $1/eg;
+            $l = sprintf('^%s$', $l);
+
+            if ($regex) {
+                $regex .= '|' . $l;
+            } else {
+                $regex .= $l;
+            }
+        }
+    }
+    if ($regex && $listname =~ m/$regex/i) {
+        $log->syslog('err', 'Prohibited "%s"', $listname);
+        return ('user', 'prohibited_listname', {argument => $listname});
+    }
+
     # Check listname on SMTP server.
     my $aliases =
         Sympa::Aliases->new(Conf::get_robot_conf($robot_id, 'alias_manager'));
@@ -211,6 +235,11 @@ Use a subclass C<Sympa::Aliases::I<name>> to manage aliases.
 
 For invalid types returns C<undef>.
 
+Note:
+For compatibility to the earlier versions of Sympa,
+if a string C<SBINDIR/alias_manager.pl> was given as $type,
+L<Sympa::Aliases::Template> subclass will be used.
+
 Optional C<I<key> =E<gt> I<value>> pairs are included in the instance as
 hash entries.
 
