@@ -8,8 +8,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2018 The Sympa Community. See the AUTHORS.md file at the
-# top-level directory of this distribution and at
+# Copyright 2018, 2021 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -61,11 +61,18 @@ sub connect {
 
     # - Configure Postgres to use ISO format dates.
     # - Set client encoding to UTF8.
+    # - Create a temporary view "dual" for portable SQL statements.
     # Note: utf8 flagging must be disabled so that we will consistently use
-    # UTF-8 bytestring as internal format.
+    #   UTF-8 bytestring as internal format.
+    # Note: PostgreSQL <= 8.0.x didn't support temporary view but >= 7.3.x
+    #   supported CREATE OR REPLACE statement.
     $self->__dbh->{pg_enable_utf8} = 0;    # For DBD::Pg 3.x
     $self->__dbh->do("SET DATESTYLE TO 'ISO';");
     $self->__dbh->do("SET NAMES 'utf8'");
+    defined $self->__dbh->do(
+        q{CREATE TEMPORARY VIEW dual AS SELECT 'X'::varchar(1) AS dummy;})
+        or $self->__dbh->do(
+        q{CREATE OR REPLACE VIEW dual AS SELECT 'X'::varchar(1) AS dummy;});
 
     return 1;
 }
