@@ -94,7 +94,8 @@ sub _twist {
     my $aliases = Sympa::Aliases->new(
         Conf::get_robot_conf($list->{'domain'}, 'alias_manager'));
     if ($aliases and $aliases->add($list)) {
-        $self->add_stash($request, 'notice', 'auto_aliases');
+        $self->add_stash($request, 'notice', 'auto_aliases',
+            { listname => $list->{'name'} .'@' . $list->{'domain'} });
     } else {
         ;
     }
