@@ -8,8 +8,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2020 The Sympa Community. See the AUTHORS.md
-# file at the top-level directory of this distribution and at
+# Copyright 2017, 2020, 2021 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -39,6 +39,7 @@ use Sympa::ListDef;
 use Sympa::Log;
 use Sympa::Tools::Data;
 use Sympa::Tools::File;
+use Sympa::Tools::Text;
 
 my $language = Sympa::Language->instance;
 my $log      = Sympa::Log->instance;
@@ -123,7 +124,15 @@ sub set_netidtoemail_db {
             q{INSERT INTO netidmap_table
               (netid_netidmap, serviceid_netidmap, email_netidmap,
                robot_netidmap)
-              VALUES (?, ?, ?, ?)},
+              SELECT ?, ?, ?, ?
+              FROM dual
+              WHERE NOT EXISTS (
+                SELECT 1
+                FROM netidmap_table
+                WHERE netid_netidmap = ? AND serviceid_netidmap = ? AND
+                      email_netidmap = ? AND robot_netidmap = ?
+              )},
+            $netid, $idpname, $email, $robot,
             $netid, $idpname, $email, $robot
         )
     ) {
