@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -8,7 +7,7 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2018, 2019, 2020, 2021 The Sympa Community. See the
+# Copyright 2017, 2018, 2019, 2020, 2021, 2022 The Sympa Community. See the
 # AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
@@ -1445,7 +1444,9 @@ sub do_search {
             }
             while (my $pattern = <$ifh>) {
                 next if $pattern =~ /\A\s*\z/ or $pattern =~ /\A[#;]/;
-                chomp $pattern;
+                $pattern =~ s/\A\s+//;
+                $pattern =~ s/\s+\z//;
+
                 $pattern =~ s/([^\w\x80-\xFF])/\\$1/g;
                 $pattern =~ s/\\\*/.*/;
                 if ($sender =~ /^$pattern$/i) {
@@ -1526,11 +1527,7 @@ sub do_verify_custom {
 }
 
 # NEVER USED.
-sub dump_all_scenarios {
-    open my $ofh, '>', '/tmp/all_scenarios';
-    Sympa::Tools::Data::dump_var(\%all_scenarios, 0, $ofh);
-    close $ofh;
-}
+#sub dump_all_scenarios;
 
 sub get_current_title {
     my $self = shift;
