@@ -8,8 +8,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2019 The Sympa Community. See the AUTHORS.md file at
-# the top-level directory of this distribution and at
+# Copyright 2017, 2019, 2021 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -417,9 +417,9 @@ sub _twist {
                     if ($action and $action =~ /do_it/i) {
                         if ($list->is_list_member($original_rcpt)) {
                             $list->delete_list_member(
-                                'users'     => [$original_rcpt],
-                                'exclude'   => ' 1',
-                                'operation' => 'auto_del',
+                                [$original_rcpt],
+                                exclude   => 1,
+                                operation => 'auto_del'
                             );
 
                             $log->syslog(
@@ -502,9 +502,9 @@ sub _twist {
         if ($action and $action =~ /do_it/i) {
             if ($list->is_list_member($who)) {
                 $list->delete_list_member(
-                    'users'     => [$who],
-                    'exclude'   => '1',
-                    'operation' => 'auto_del',
+                    [$who],
+                    exclude   => 1,
+                    operation => 'auto_del'
                 );
                 $log->syslog(
                     'notice',
