@@ -8,8 +8,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2018, 2019 The Sympa Community. See the AUTHORS.md file at
-# the top-level directory of this distribution and at
+# Copyright 2017, 2018, 2019, 2022 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -82,9 +82,8 @@ sub _twist {
         $message->replace_header('From',
             $list->{'admin'}{'anonymous_sender'});
         $message->delete_header('Resent-From');
-        my $new_id =
-            $list->{'name'} . '.' . $message->{xsequence} . '@anonymous';
-        $message->replace_header('Message-Id', "<$new_id>");
+        my $new_id = Sympa::unique_message_id($list);
+        $message->replace_header('Message-Id', $new_id);
         $message->delete_header('Resent-Message-Id');
 
         # Duplicate topic file by new message ID.
