@@ -8,8 +8,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2019 The Sympa Community. See the AUTHORS.md file at
-# the top-level directory of this distribution and at
+# Copyright 2019, 2021 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -35,15 +35,8 @@ BEGIN { eval 'use Data::Password'; }
 use Conf;
 use Sympa::Language;
 
-sub tmp_passwd {
-    my $email = shift;
-
-    my $cookie = $Conf::Conf{'cookie'};
-    $cookie = '' unless defined $cookie;
-
-    return (
-        'init' . substr(Digest::MD5::md5_hex(join '/', $cookie, $email), -8));
-}
+# Deprecated.  No longer used.
+#sub tmp_passwd;
 
 # No longer used, Use _decrypt_rc4_password() in upgrade_sympa_password.pl.
 #sub ciphersaber_installed;
